@@ -1,12 +1,14 @@
 """Base class used to define the interface for derivative approximation schemes."""
 from collections import defaultdict
+
 from scipy.sparse import coo_matrix
 import numpy as np
+
 from openmdao.utils.array_utils import sub2full_indices, get_input_idx_split
 import openmdao.utils.coloring as coloring_mod
+from openmdao.utils.mpi import MPI
 from openmdao.jacobians.jacobian import Jacobian
-
-_full_slice = slice(None)
+from openmdao.vectors.vector import _full_slice
 
 
 class ApproximationScheme(object):
@@ -45,6 +47,17 @@ class ApproximationScheme(object):
         self._approx_groups_cached_under_cs = False
         self._exec_dict = defaultdict(list)
 
+    def __repr__(self):
+        """
+        Return a simple string representation.
+
+        Returns
+        -------
+        str
+            String containing class name and added approximation keys.
+        """
+        return f"{self.__class__.__name__}: {list(self._exec_dict.keys())}"
+
     def _reset(self):
         """
         Get rid of any existing approx groups.
@@ -139,7 +152,6 @@ class ApproximationScheme(object):
         approx_wrt_idx = system._owns_approx_wrt_idx
 
         out_slices = outputs.get_slice_dict()
-        in_slices = inputs.get_slice_dict()
 
         is_total = isinstance(system, Group)
 
@@ -199,7 +211,7 @@ class ApproximationScheme(object):
 
         if len(full_wrts) != len(wrt_matches) or approx_wrt_idx:
             if is_total and system.pathname == '':  # top level approx totals
-                full_wrt_sizes = [abs2meta[wrt]['size'] for wrt in wrt_names]
+                full_wrt_sizes = [abs2meta[wrt]['size'] for wrt in full_wrts]
             else:
                 _, full_wrt_sizes = system._get_partials_var_sizes()
 
@@ -278,6 +290,10 @@ class ApproximationScheme(object):
 
     def _compute_approximations(self, system, jac, total, under_cs):
         from openmdao.core.component import Component
+
+        # Set system flag that we're under approximation to true
+        system._set_approx_mode(True)
+
         # Clean vector for results
         results_array = system._outputs._data.copy() if total else system._residuals._data.copy()
 
@@ -291,7 +307,10 @@ class ApproximationScheme(object):
         par_fd_w_serial_model = use_parallel_fd and system._num_par_fd == system._full_comm.size
         num_par_fd = system._num_par_fd if use_parallel_fd else 1
         is_parallel = use_parallel_fd or system.comm.size > 1
-        is_distributed = isinstance(system, Component) and system.options['distributed']
+        if isinstance(system, Component):
+            is_distributed = system.options['distributed']
+        else:
+            is_distributed = system._has_distrib_vars and not use_parallel_fd
 
         results = defaultdict(list)
         iproc = system.comm.rank
@@ -439,6 +458,9 @@ class ApproximationScheme(object):
                 else:
                     jac[key] = _from_dense(jacobian, key, oview, rows_reduced, cols_reduced)
 
+        # Set system flag that we're under approximation to false
+        system._set_approx_mode(False)
+
 
 def _from_dense(jac, key, subjac, reduced_rows=_full_slice, reduced_cols=_full_slice):
     """
@@ -518,7 +540,6 @@ def _get_wrt_subjacs(system, approxs):
             J[wrt] = {'ofs': set(), 'tot_rows': 0, 'directional': options['directional'],
                       'vector': options['vector']}
 
-        tmpJ = None
         if of not in ofdict and (approx_of is None or (approx_of and of in approx_of)):
             J[wrt]['ofs'].add(of)
             if of in approx_of_idx:
@@ -581,7 +602,12 @@ def _get_wrt_subjacs(system, approxs):
                         full_idxs.append(np.arange(slc.start, slc.stop)[approx_of_idx[sof]])
                     else:
                         full_idxs.append(range(slc.start, slc.stop))
-            J[wrt]['loc_outvec_idxs'] = np.hstack(full_idxs)
+            if full_idxs:
+                J[wrt]['loc_outvec_idxs'] = np.hstack(full_idxs)
+            else:
+                # guard for empty
+                # which can happen if no vois are on this processor (e.g. pargroup)
+                J[wrt]['loc_outvec_idxs'] = np.array([])
         else:
             J[wrt]['loc_outvec_idxs'] = _full_slice
 
