@@ -4,7 +4,7 @@ from collections import namedtuple, defaultdict
 import numpy as np
 
 from openmdao.approximation_schemes.approximation_scheme import ApproximationScheme, \
-    _gather_jac_results
+    _gather_jac_results, _full_slice
 from openmdao.utils.array_utils import sub2full_indices
 from openmdao.utils.coloring import Coloring
 
@@ -28,8 +28,6 @@ FD_COEFFS = {
                            current_coeff=0.),
 }
 
-_full_slice = slice(None)
-
 
 def _generate_fd_coeff(form, order, system):
     """
@@ -303,21 +301,15 @@ class FiniteDifference(ApproximationScheme):
         if total:
             system.run_solve_nonlinear()
             self._results_tmp[:] = system._outputs._data
-            system._outputs._data[:] = self._starting_outs
         else:
             system.run_apply_nonlinear()
             self._results_tmp[:] = system._residuals._data
+
         system._residuals._data[:] = self._starting_resids
 
         # save results and restore starting inputs/outputs
         system._inputs._data[:] = self._starting_ins
-
-        # if results_vec are the residuals then we need to remove the delta's we added earlier
-        # to the outputs
-        if not total:
-            for vec, idxs in idx_info:
-                if vec is system._outputs:
-                    vec._data[idxs] -= delta
+        system._outputs._data[:] = self._starting_outs
 
         return self._results_tmp
 
