@@ -103,54 +103,6 @@ class EQConstraintComp(ExplicitComponent):
                                use_mult, mult_name, mult_val, normalize, add_constraint, ref, ref0,
                                adder, scaler, **kwargs)
 
-    def _post_configure(self):
-        """
-        Define the independent variables, output variables, and partials.
-        """
-        # set static mode to False because we are doing things that would normally be done in setup
-        self._static_mode = False
-
-        for name, options in self._output_vars.items():
-
-            meta = self.add_output(name, **options['kwargs'])
-
-            shape = meta['shape']
-
-            for s in ('lhs', 'rhs', 'mult'):
-                if options['{0}_name'.format(s)] is None:
-                    options['{0}_name'.format(s)] = '{0}:{1}'.format(s, name)
-
-            self.add_input(options['lhs_name'],
-                           val=np.ones(shape),
-                           units=options['eq_units'])
-
-            self.add_input(options['rhs_name'],
-                           val=options['rhs_val'] * np.ones(shape),
-                           units=options['eq_units'])
-
-            if options['use_mult']:
-                self.add_input(options['mult_name'],
-                               val=options['mult_val'] * np.ones(shape),
-                               units=None)
-
-            self._scale_factor = np.ones(shape)
-            self._dscale_drhs = np.ones(shape)
-
-            ar = np.arange(np.prod(shape))
-            self.declare_partials(of=name, wrt=options['lhs_name'], rows=ar, cols=ar, val=1.0)
-            self.declare_partials(of=name, wrt=options['rhs_name'], rows=ar, cols=ar, val=1.0)
-
-            if options['use_mult']:
-                self.declare_partials(of=name, wrt=options['mult_name'], rows=ar, cols=ar, val=1.0)
-
-            if options['add_constraint']:
-                self.add_constraint(name, equals=0., ref0=options['ref0'], ref=options['ref'],
-                                    adder=options['adder'], scaler=options['scaler'])
-
-        self._static_mode = True
-
-        super(EQConstraintComp, self)._post_configure()
-
     def compute(self, inputs, outputs):
         """
         Calculate the output for each equality constraint.
@@ -301,17 +253,52 @@ class EQConstraintComp(ExplicitComponent):
             Additional arguments to be passed for the creation of the output variable.
             (see `add_output` method).
         """
-        self._output_vars[name] = {'kwargs': kwargs,
-                                   'eq_units': eq_units,
-                                   'lhs_name': lhs_name,
-                                   'rhs_name': rhs_name,
-                                   'rhs_val': rhs_val,
-                                   'use_mult': use_mult,
-                                   'mult_name': mult_name,
-                                   'mult_val': mult_val,
-                                   'normalize': normalize,
-                                   'add_constraint': add_constraint,
-                                   'ref': ref,
-                                   'ref0': ref0,
-                                   'adder': adder,
-                                   'scaler': scaler}
+        self._output_vars[name] = options = {'kwargs': kwargs,
+                                             'eq_units': eq_units,
+                                             'lhs_name': lhs_name,
+                                             'rhs_name': rhs_name,
+                                             'rhs_val': rhs_val,
+                                             'use_mult': use_mult,
+                                             'mult_name': mult_name,
+                                             'mult_val': mult_val,
+                                             'normalize': normalize,
+                                             'add_constraint': add_constraint,
+                                             'ref': ref,
+                                             'ref0': ref0,
+                                             'adder': adder,
+                                             'scaler': scaler}
+
+        meta = self.add_output(name, **options['kwargs'])
+
+        shape = meta['shape']
+
+        for s in ('lhs', 'rhs', 'mult'):
+            if options['{0}_name'.format(s)] is None:
+                options['{0}_name'.format(s)] = '{0}:{1}'.format(s, name)
+
+        self.add_input(options['lhs_name'],
+                       val=np.ones(shape),
+                       units=options['eq_units'])
+
+        self.add_input(options['rhs_name'],
+                       val=options['rhs_val'] * np.ones(shape),
+                       units=options['eq_units'])
+
+        if options['use_mult']:
+            self.add_input(options['mult_name'],
+                           val=options['mult_val'] * np.ones(shape),
+                           units=None)
+
+        self._scale_factor = np.ones(shape)
+        self._dscale_drhs = np.ones(shape)
+
+        ar = np.arange(np.prod(shape))
+        self.declare_partials(of=name, wrt=options['lhs_name'], rows=ar, cols=ar, val=1.0)
+        self.declare_partials(of=name, wrt=options['rhs_name'], rows=ar, cols=ar, val=1.0)
+
+        if options['use_mult']:
+            self.declare_partials(of=name, wrt=options['mult_name'], rows=ar, cols=ar, val=1.0)
+
+        if options['add_constraint']:
+            self.add_constraint(name, equals=0., ref0=options['ref0'], ref=options['ref'],
+                                adder=options['adder'], scaler=options['scaler'])
