@@ -33,6 +33,11 @@ class TestKSFunction(unittest.TestCase):
 
         assert_near_equal(max(prob['comp.y2']), prob['ks.KS'][0])
 
+    def test_bad_units(self):
+        with self.assertRaises(ValueError) as ctx:
+            om.KSComp(units='wtfu')
+        self.assertEqual(str(ctx.exception), "The units 'wtfu' are invalid.")
+
     def test_vectorized(self):
         prob = om.Problem()
         model = prob.model
@@ -42,19 +47,19 @@ class TestKSFunction(unittest.TestCase):
         x[1, :] = np.array([13.0, 11.0, 5.0, 17.0, 3.0])*2
         x[2, :] = np.array([11.0, 3.0, 17.0, 5.0, 13.0])*3
 
-        model.add_subsystem('px', om.IndepVarComp(name="x", val=x))
         model.add_subsystem('ks', om.KSComp(width=5, vec_size=3))
-        model.connect('px.x', 'ks.g')
 
-        model.add_design_var('px.x')
+        model.add_design_var('ks.g')
         model.add_constraint('ks.KS', upper=0.0)
 
         prob.setup()
+        prob.set_val('ks.g', x)
         prob.run_driver()
 
-        assert_near_equal(prob['ks.KS'][0], 17.0)
-        assert_near_equal(prob['ks.KS'][1], 34.0)
-        assert_near_equal(prob['ks.KS'][2], 51.0)
+
+        assert_near_equal(prob.get_val('ks.KS', indices=0), 17.0)
+        assert_near_equal(prob.get_val('ks.KS', indices=1), 34.0)
+        assert_near_equal(prob.get_val('ks.KS', indices=2), 51.0)
 
         partials = prob.check_partials(includes=['ks'], out_stream=None)
 
@@ -165,36 +170,35 @@ class TestKSFunction(unittest.TestCase):
         prob = om.Problem()
         model = prob.model
 
-        model.add_subsystem('px', om.IndepVarComp('x', val=np.array([5.0, 4.0])))
         model.add_subsystem('comp', om.ExecComp('y = 3.0*x', x=np.zeros((2, )), y=np.zeros((2, ))))
         model.add_subsystem('ks', om.KSComp(width=2))
 
-        model.connect('px.x', 'comp.x')
         model.connect('comp.y', 'ks.g')
 
         model.ks.options['upper'] = 16.0
         prob.setup()
+        prob.set_val('comp.x', np.array([5.0, 4.0]))
         prob.run_model()
 
-        assert_near_equal(prob['ks.KS'][0], -1.0)
+        assert_near_equal(prob.get_val('ks.KS', indices=0), -1.0)
 
     def test_lower_flag(self):
 
         prob = om.Problem()
         model = prob.model
 
-        model.add_subsystem('px', om.IndepVarComp('x', val=np.array([5.0, 4.0])))
         model.add_subsystem('comp', om.ExecComp('y = 3.0*x', x=np.zeros((2, )), y=np.zeros((2, ))))
+
         model.add_subsystem('ks', om.KSComp(width=2))
 
-        model.connect('px.x', 'comp.x')
         model.connect('comp.y', 'ks.g')
 
         model.ks.options['lower_flag'] = True
         prob.setup()
+        prob.set_val('comp.x', np.array([5.0, 4.0]))
         prob.run_model()
 
-        assert_near_equal(prob['ks.KS'][0], -12.0)
+        assert_near_equal(prob.get_val('ks.KS', indices=0), -12.0)
 
 
 class TestKSFunctionFeatures(unittest.TestCase):
@@ -207,18 +211,19 @@ class TestKSFunctionFeatures(unittest.TestCase):
         prob = om.Problem()
         model = prob.model
 
-        model.add_subsystem('px', om.IndepVarComp('x', val=np.array([5.0, 4.0])))
-        model.add_subsystem('comp', om.ExecComp('y = 3.0*x', x=np.zeros((2, )),
-                                                y=np.zeros((2, ))))
+        model.add_subsystem('comp', om.ExecComp('y = 3.0*x',
+                                                x=np.zeros((2, )),
+                                                y=np.zeros((2, ))), promotes_inputs=['x'])
+
         model.add_subsystem('ks', om.KSComp(width=2))
 
-        model.connect('px.x', 'comp.x')
         model.connect('comp.y', 'ks.g')
 
         prob.setup()
+        prob.set_val('x', np.array([5.0, 4.0]))
         prob.run_model()
 
-        assert_near_equal(prob['ks.KS'][0], 15.0)
+        assert_near_equal(prob.get_val('ks.KS'), [[15.0]])
 
     def test_vectorized(self):
         import numpy as np
@@ -228,19 +233,18 @@ class TestKSFunctionFeatures(unittest.TestCase):
         prob = om.Problem()
         model = prob.model
 
-        model.add_subsystem('px', om.IndepVarComp('x', val=np.array([[5.0, 4.0], [10.0, 8.0]])))
-        model.add_subsystem('comp', om.ExecComp('y = 3.0*x', x=np.zeros((2, 2)),
-                                                y=np.zeros((2, 2))))
+        model.add_subsystem('comp', om.ExecComp('y = 3.0*x',
+                                                x=np.zeros((2, 2)),
+                                                y=np.zeros((2, 2))), promotes_inputs=['x'])
         model.add_subsystem('ks', om.KSComp(width=2, vec_size=2))
 
-        model.connect('px.x', 'comp.x')
         model.connect('comp.y', 'ks.g')
 
         prob.setup()
+        prob.set_val('x', np.array([[5.0, 4.0], [10.0, 8.0]]))
         prob.run_model()
 
-        assert_near_equal(prob['ks.KS'][0], 15.0)
-        assert_near_equal(prob['ks.KS'][1], 30.0)
+        assert_near_equal(prob.get_val('ks.KS'), np.array([[15], [30]]))
 
     def test_upper(self):
         import numpy as np
@@ -250,19 +254,19 @@ class TestKSFunctionFeatures(unittest.TestCase):
         prob = om.Problem()
         model = prob.model
 
-        model.add_subsystem('px', om.IndepVarComp('x', val=np.array([5.0, 4.0])))
-        model.add_subsystem('comp', om.ExecComp('y = 3.0*x', x=np.zeros((2, )),
-                                                y=np.zeros((2, ))))
+        model.add_subsystem('comp', om.ExecComp('y = 3.0*x',
+                                                x=np.zeros((2, )),
+                                                y=np.zeros((2, ))), promotes_inputs=['x'])
         model.add_subsystem('ks', om.KSComp(width=2))
 
-        model.connect('px.x', 'comp.x')
         model.connect('comp.y', 'ks.g')
 
         model.ks.options['upper'] = 16.0
         prob.setup()
+        prob.set_val('x', np.array([5.0, 4.0]))
         prob.run_model()
 
-        assert_near_equal(prob['ks.KS'][0], -1.0)
+        assert_near_equal(prob['ks.KS'], np.array([[-1.0]]))
 
     def test_lower_flag(self):
         import numpy as np
@@ -272,19 +276,20 @@ class TestKSFunctionFeatures(unittest.TestCase):
         prob = om.Problem()
         model = prob.model
 
-        model.add_subsystem('px', om.IndepVarComp('x', val=np.array([5.0, 4.0])))
-        model.add_subsystem('comp', om.ExecComp('y = 3.0*x', x=np.zeros((2, )),
-                                                y=np.zeros((2, ))))
+        model.add_subsystem('comp', om.ExecComp('y = 3.0*x',
+                                                x=np.zeros((2, )),
+                                                y=np.zeros((2, ))), promotes_inputs=['x'])
+
         model.add_subsystem('ks', om.KSComp(width=2))
 
-        model.connect('px.x', 'comp.x')
         model.connect('comp.y', 'ks.g')
 
         model.ks.options['lower_flag'] = True
         prob.setup()
+        prob.set_val('x', np.array([5.0, 4.0]))
         prob.run_model()
 
-        assert_near_equal(prob['ks.KS'][0], -12.0)
+        assert_near_equal(prob.get_val('ks.KS'), [[-12.0]])
 
     def test_add_constraint(self):
         import numpy as np
@@ -297,29 +302,29 @@ class TestKSFunctionFeatures(unittest.TestCase):
 
         prob.driver = om.ScipyOptimizeDriver()
 
-        ivc = model.add_subsystem('ivc', om.IndepVarComp())
-        ivc.add_output('x', val=np.linspace(-np.pi/2, np.pi/2, n))
-        ivc.add_output('k', val=5.0)
+        model.add_subsystem('comp', om.ExecComp('y = -3.0*x**2 + k',
+                                                x=np.zeros((n, )),
+                                                y=np.zeros((n, )),
+                                                k=0.0), promotes_inputs=['x', 'k'])
 
-        model.add_subsystem('comp', om.ExecComp('y = -3.0*x**2 + k', x=np.zeros((n, )),
-                                                y=np.zeros((n, )), k=0.0))
         model.add_subsystem('ks', om.KSComp(width=n, upper=4.0, add_constraint=True))
 
-        model.add_design_var('ivc.k', lower=-10, upper=10)
-        model.add_objective('ivc.k', scaler=-1)
+        model.add_design_var('k', lower=-10, upper=10)
+        model.add_objective('k', scaler=-1)
 
-        model.connect('ivc.x', 'comp.x')
-        model.connect('ivc.k', 'comp.k')
         model.connect('comp.y', 'ks.g')
 
         prob.setup()
+        prob.set_val('x', np.linspace(-np.pi/2, np.pi/2, n))
+        prob.set_val('k', 5.)
+
         prob.run_driver()
 
         self.assertTrue(max(prob.get_val('comp.y')) <= 4.0)
 
         fig, ax = plt.subplots()
 
-        x = prob.get_val('ivc.x')
+        x = prob.get_val('x')
         y = prob.get_val('comp.y')
 
         ax.plot(x, y, 'r.')
@@ -327,10 +332,27 @@ class TestKSFunctionFeatures(unittest.TestCase):
         ax.set_xlabel('x')
         ax.set_ylabel('y')
         ax.grid(True)
-        ax.text(-0.25, 0, f"k = {prob.get_val('ivc.k')[0]:6.3f}")
+        ax.text(-0.25, 0, f"k = {prob.get_val('k')[0]:6.3f}")
 
         plt.show()
 
+    def test_units(self):
+        import openmdao.api as om
+        from openmdao.utils.units import convert_units
+
+        n = 10
+
+        model = om.Group()
+
+        model.add_subsystem('ks', om.KSComp(width=n, units='m'), promotes_inputs=[('g', 'x')])
+        model.set_input_defaults('x', range(n), units='ft')
+
+        prob = om.Problem(model=model)
+        prob.setup()
+        prob.run_model()
+
+        assert_near_equal(prob.get_val('ks.KS', indices=0), np.amax(prob.get_val('x')), tolerance=1e-8)
+
 
 if __name__ == "__main__":
     unittest.main()
