@@ -154,12 +154,16 @@ class _DiscreteVal(object):
         self._val *= val
         return self
 
+    def __eq__(self, val):
+        if isinstance(val, _DiscreteVal):
+            return self._val == val.getval()
+        return False
 
 class PathCompEx(om.ExplicitComponent):
 
     def setup(self):
-        self.add_discrete_input('x', val=self.pathname)
-        self.add_discrete_output('y', val=self.pathname + '/')
+        self.add_discrete_input('x', val='')
+        self.add_discrete_output('y', val='')
 
     def compute(self, inputs, outputs, discrete_inputs, discrete_outputs):
         discrete_outputs['y'] = discrete_inputs['x'] + self.pathname + '/'
@@ -329,16 +333,14 @@ class DiscreteTestCase(unittest.TestCase):
     def test_list_inputs_outputs_promoted(self):
         model = om.Group()
 
-        indep = om.IndepVarComp()
-        indep.add_discrete_output('x', 11)
-
-        model.add_subsystem('indep', indep, promotes_outputs=['x'])
-
         model.add_subsystem('expl', ModCompEx(3), promotes_inputs=['x'])
         model.add_subsystem('impl', ModCompIm(3), promotes_inputs=['x'])
 
         prob = om.Problem(model)
         prob.setup()
+
+        prob['x'] = 11
+
         prob.run_model()
 
         #
@@ -370,19 +372,20 @@ class DiscreteTestCase(unittest.TestCase):
         #
         stream = StringIO()
 
-        model.list_outputs(prom_name=True, out_stream=stream)
+        model.list_outputs(prom_name=True, out_stream=stream, list_autoivcs=True)
 
         text = stream.getvalue().split('\n')
 
         expected = [
-            "3 Explicit Output(s) in 'model'",
+            "4 Explicit Output(s) in 'model'",
             "-------------------------------",
             "",
             "varname  value  prom_name",
             "-------  -----  ---------",
             "model",
-            "  indep",
-            "    x    11     x",
+            "  _auto_ivc",
+            "    v0    [10.]  _auto_ivc.v0",
+            "    v1    11     _auto_ivc.v1",
             "  expl",
             "    b    [20.]  expl.b",
             "    y    2      expl.y",
@@ -556,45 +559,25 @@ class DiscreteTestCase(unittest.TestCase):
 
         np.testing.assert_almost_equal(J, np.array([[3.]]))
 
-    def test_discrete_unconn_inputs(self):
-        prob = om.Problem()
-        model = prob.model
-
-        c1 = model.add_subsystem('c1', PathCompEx(), promotes=['x'])
-        c2 = model.add_subsystem('c2', PathCompEx(), promotes=['x'])
-
-        testlogger = TestLogger()
-
-        prob.setup(check=['unconnected_inputs'], logger=testlogger)
-        prob.run_model()
-
-        expected_warning_1 = (
-            "The following inputs are not connected:\n"
-            "   x  (p):\n"
-            "      c1.x  c1\n"
-            "      c2.x  c2\n"
-        )
-
-        self.assertTrue(testlogger.contains('warning', expected_warning_1))
-
     def test_discrete_deriv_implicit(self):
         prob = om.Problem()
         model = prob.model
 
         indep = model.add_subsystem('indep', om.IndepVarComp())
         indep.add_output('x', 1.0, ref=10.)
-        indep.add_discrete_output('N', 1)
 
-        comp = model.add_subsystem('comp', CompDiscWDerivsImplicit())
+        comp = model.add_subsystem('comp', CompDiscWDerivsImplicit(), promotes=['N'])
         sink = model.add_subsystem('sink', MixedCompDiscIn(1.0))
         model.connect('indep.x', 'comp.y2_actual')
-        model.connect('indep.N', 'comp.N')
         model.connect('comp.Nout', 'sink.x')
 
         model.add_design_var('indep.x')
         model.add_objective('comp.y2_command')
 
         prob.setup()
+
+        prob['N'] = 1
+
         prob.run_model()
 
         J = prob.compute_totals(return_format='array')
@@ -734,9 +717,6 @@ class DiscretePromTestCase(unittest.TestCase):
         prob = om.Problem()
         model = prob.model
 
-        indep = model.add_subsystem('indep', om.IndepVarComp(), promotes_outputs=['x'])
-        indep.add_discrete_output('x', 'indep/')
-
         G = model.add_subsystem('G', om.ParallelGroup(), promotes_inputs=['x'])
 
         G1 = G.add_subsystem('G1', om.Group(), promotes_inputs=['x'], promotes_outputs=['y'])
@@ -756,12 +736,15 @@ class DiscretePromTestCase(unittest.TestCase):
         model.connect('G.G2.y', 'C4.x')
 
         prob.setup()
+
+        prob['x'] = 'indep/'
+
         prob.run_model()
 
         self.assertEqual(prob['C3.y'], 'indep/G.G1.C1_1/G.G1.C1_2/C3/')
         self.assertEqual(prob['C4.y'], 'indep/G.G2.C2_1/G.G2.C2_2/C4/')
 
-        prob['indep.x'] = 'foobar/'
+        prob['x'] = 'foobar/'
         prob.run_model()
 
         self.assertEqual(prob['C3.y'], 'foobar/G.G1.C1_1/G.G1.C1_2/C3/')
@@ -771,9 +754,6 @@ class DiscretePromTestCase(unittest.TestCase):
         prob = om.Problem()
         model = prob.model
 
-        indep = model.add_subsystem('indep', om.IndepVarComp(), promotes_outputs=['x'])
-        indep.add_discrete_output('x', _DiscreteVal(19))
-
         G = model.add_subsystem('G', om.ParallelGroup(), promotes_inputs=['x'])
 
         G1 = G.add_subsystem('G1', om.Group(), promotes_inputs=['x'], promotes_outputs=['y'])
@@ -782,7 +762,7 @@ class DiscretePromTestCase(unittest.TestCase):
         G1.connect('C1_1.y', 'C1_2.x')
 
         G2 = G.add_subsystem('G2', om.Group(), promotes_inputs=['x'])
-        G2.add_subsystem('C2_1', ObjAdderCompEx(_DiscreteVal(1)), promotes_inputs=['x'])
+        G2.add_subsystem('C2_1', ObjAdderCompEx(_DiscreteVal(5)), promotes_inputs=['x'])
         G2.add_subsystem('C2_2', ObjAdderCompEx(_DiscreteVal(11)), promotes_outputs=['y'])
         G2.connect('C2_1.y', 'C2_2.x')
 
@@ -793,10 +773,13 @@ class DiscretePromTestCase(unittest.TestCase):
         model.connect('G.G2.y', 'C4.x')
 
         prob.setup()
+
+        prob['x'] =  _DiscreteVal(19)
+
         prob.run_model()
 
         self.assertEqual(prob['C3.y'].getval(), 40)
-        self.assertEqual(prob['C4.y'].getval(), 52)
+        self.assertEqual(prob['C4.y'].getval(), 56)
 
         def _var_iter(obj):
             name = obj['name']
@@ -813,7 +796,7 @@ class DiscretePromTestCase(unittest.TestCase):
         # add a test to see if discrete vars show up in n2
         data = _get_viewer_data(prob)
         findvars = [
-            'indep.x',
+            '_auto_ivc.v0',
             'G.G1.C1_1.x',
             'G.G1.C1_1.y',
             'G.G1.C1_2.x',
@@ -832,6 +815,7 @@ class DiscretePromTestCase(unittest.TestCase):
 
 
 class DiscreteFeatureTestCase(unittest.TestCase):
+
     def test_feature_discrete(self):
         import numpy as np
         import openmdao.api as om
@@ -859,15 +843,16 @@ class DiscreteFeatureTestCase(unittest.TestCase):
 
         # build the model
         prob = om.Problem()
-        indeps = prob.model.add_subsystem('indeps', om.IndepVarComp(), promotes=['*'])
-        indeps.add_output('r_m', 3.2, units="ft")
-        indeps.add_output('chord', .3, units='ft')
-        indeps.add_discrete_output('num_blades', 2)
 
         prob.model.add_subsystem('SolidityComp', BladeSolidity(),
                                  promotes_inputs=['r_m', 'chord', 'num_blades'])
 
         prob.setup()
+
+        prob.set_val('num_blades', 2)
+        prob.set_val('r_m', 3.2)
+        prob.set_val('chord', .3)
+
         prob.run_model()
 
         # minimum value
@@ -915,13 +900,13 @@ class DiscreteFeatureTestCase(unittest.TestCase):
 
         model.add_subsystem('comp', ImpWithInitial())
 
-        model.nonlinear_solver = om.NewtonSolver(solve_subsystems=False)
-        model.linear_solver = om.ScipyKrylov()
+        model.comp.nonlinear_solver = om.NewtonSolver(solve_subsystems=False)
+        model.comp.linear_solver = om.ScipyKrylov()
 
         prob.setup()
         prob.run_model()
 
-        assert_near_equal(prob['comp.x'], 3., 1e-4)
+        assert_near_equal(prob.get_val('comp.x'), 3., 1e-4)
 
 
 if __name__ == "__main__":
