@@ -33,7 +33,7 @@ class TestDriver(unittest.TestCase):
         prob.run_driver()
 
         designvars = prob.driver.get_design_var_values()
-        self.assertEqual(designvars['pz.z'][0], 5.0 )
+        self.assertEqual(designvars['z'][0], 5.0 )
 
         designvars = prob.driver.get_objective_values()
         self.assertEqual(designvars['obj_cmp.obj'], prob['obj'] )
@@ -57,10 +57,10 @@ class TestDriver(unittest.TestCase):
         prob.final_setup()
 
         dv = prob.driver.get_design_var_values()
-        self.assertEqual(dv['pz.z'][0], 1.0)
-        self.assertEqual(dv['pz.z'][1], -0.5)
+        self.assertEqual(dv['z'][0], 1.0)
+        self.assertEqual(dv['z'][1], -0.5)
 
-        prob.driver.set_design_var('pz.z', np.array((2.0, -2.0)))
+        prob.driver.set_design_var('z', np.array((2.0, -2.0)))
         self.assertEqual(prob['z'][0], 7.0)
         self.assertEqual(prob['z'][1], -1.0)
 
@@ -124,10 +124,10 @@ class TestDriver(unittest.TestCase):
         prob.setup()
         prob.run_model()
 
-        derivs = prob.driver._compute_totals(of=['obj_cmp.obj', 'con_cmp1.con1'], wrt=['pz.z'],
+        derivs = prob.driver._compute_totals(of=['obj_cmp.obj', 'con_cmp1.con1'], wrt=['z'],
                                              return_format='dict')
-        assert_near_equal(base[('con1', 'z')][0], derivs['con_cmp1.con1']['pz.z'][0], 1e-5)
-        assert_near_equal(base[('obj', 'z')][0]*2.0, derivs['obj_cmp.obj']['pz.z'][0], 1e-5)
+        assert_near_equal(base[('con1', 'z')][0], derivs['con_cmp1.con1']['z'][0], 1e-5)
+        assert_near_equal(base[('obj', 'z')][0]*2.0, derivs['obj_cmp.obj']['z'][0], 1e-5)
 
     def test_vector_scaled_derivs(self):
 
@@ -723,10 +723,6 @@ class TestDriverFeature(unittest.TestCase):
         prob = om.Problem()
         model = prob.model
 
-        ivc = om.IndepVarComp()
-        ivc.add_output('x', 35.0, units='degF', lower=32.0, upper=212.0)
-
-        model.add_subsystem('p', ivc, promotes=['x'])
         model.add_subsystem('comp1', om.ExecComp('y1 = 2.0*x',
                                                  x={'value': 2.0, 'units': 'degF'},
                                                  y1={'value': 2.0, 'units': 'degF'}),
@@ -737,6 +733,8 @@ class TestDriverFeature(unittest.TestCase):
                                                  y2={'value': 2.0, 'units': 'degF'}),
                             promotes=['x', 'y2'])
 
+        model.set_input_defaults('x', 35.0, units='degF')
+
         model.add_design_var('x', units='degC', lower=0.0, upper=100.0)
         model.add_constraint('y1', units='degC', lower=0.0, upper=100.0)
         model.add_objective('y2', units='degC')
@@ -745,14 +743,14 @@ class TestDriverFeature(unittest.TestCase):
         prob.run_driver()
 
         print('Model variables')
-        assert_near_equal(prob['p.x'][0], 35.0, 1e-8)
-        assert_near_equal(prob['comp2.y2'][0], 105.0, 1e-8)
-        assert_near_equal(prob['comp1.y1'][0], 70.0, 1e-8)
+        assert_near_equal(prob.get_val('x', indices=[0]), 35.0, 1e-8)
+        assert_near_equal(prob.get_val('comp2.y2', indices=[0]), 105.0, 1e-8)
+        assert_near_equal(prob.get_val('comp1.y1', indices=[0]), 70.0, 1e-8)
 
         print('')
         print('Driver variables')
         dv = prob.driver.get_design_var_values()
-        assert_near_equal(dv['p.x'][0], 3.0 * 5 / 9, 1e-8)
+        assert_near_equal(dv['x'][0], 3.0 * 5 / 9, 1e-8)
 
         obj = prob.driver.get_objective_values(driver_scaling=True)
         assert_near_equal(obj['comp2.y2'][0], 73.0 * 5 / 9, 1e-8)
