@@ -1,5 +1,6 @@
 """IndepVarComp tests used in the IndepVarComp feature doc."""
 import unittest
+import numpy as np
 
 import openmdao.api as om
 from openmdao.utils.assert_utils import assert_near_equal
@@ -14,10 +15,10 @@ class TestIndepVarComp(unittest.TestCase):
         comp = om.IndepVarComp('indep_var')
         prob = om.Problem(comp).setup()
 
-        assert_near_equal(prob['indep_var'], 1.0)
+        assert_near_equal(prob.get_val('indep_var'), 1.0)
 
-        prob['indep_var'] = 2.0
-        assert_near_equal(prob['indep_var'], 2.0)
+        prob.set_val('indep_var', 2.0)
+        assert_near_equal(prob.get_val('indep_var'), 2.0)
 
     def test_simple_default(self):
         """Define one independent variable with a default value."""
@@ -26,7 +27,7 @@ class TestIndepVarComp(unittest.TestCase):
         comp = om.IndepVarComp('indep_var', val=2.0)
         prob = om.Problem(comp).setup()
 
-        assert_near_equal(prob['indep_var'], 2.0)
+        assert_near_equal(prob.get_val('indep_var'), 2.0)
 
     def test_simple_kwargs(self):
         """Define one independent variable with a default value and additional options."""
@@ -35,7 +36,7 @@ class TestIndepVarComp(unittest.TestCase):
         comp = om.IndepVarComp('indep_var', val=2.0, units='m', lower=0, upper=10)
         prob = om.Problem(comp).setup()
 
-        assert_near_equal(prob['indep_var'], 2.0)
+        assert_near_equal(prob.get_val('indep_var'), 2.0)
 
     def test_simple_array(self):
         """Define one independent array variable."""
@@ -51,7 +52,7 @@ class TestIndepVarComp(unittest.TestCase):
         comp = om.IndepVarComp('indep_var', val=array)
         prob = om.Problem(comp).setup()
 
-        assert_near_equal(prob['indep_var'], array)
+        assert_near_equal(prob.get_val('indep_var'), array)
 
     def test_add_output(self):
         """Define two independent variables using the add_output method."""
@@ -63,15 +64,16 @@ class TestIndepVarComp(unittest.TestCase):
 
         prob = om.Problem(comp).setup()
 
-        assert_near_equal(prob['indep_var_1'], 1.0)
-        assert_near_equal(prob['indep_var_2'], 2.0)
+        assert_near_equal(prob.get_val('indep_var_1'), 1.0)
+        assert_near_equal(prob.get_val('indep_var_2'), 2.0)
 
     def test_invalid_tags(self):
         with self.assertRaises(TypeError) as cm:
             comp = om.IndepVarComp('indep_var', tags=99)
 
         self.assertEqual(str(cm.exception),
-            "The tags argument should be str, set, or list: 99")
+            "IndepVarComp: Value (99) of option 'tags' has type 'int', "
+            "but one of types ('str', 'list') was expected.")
 
     def test_simple_with_tags(self):
         """Define one independent variable and set its value. Try filtering with tag"""
@@ -182,7 +184,24 @@ class TestIndepVarComp(unittest.TestCase):
         prob['p.x1'][0] = 0.5
         prob.run_model()
 
-        assert_near_equal(prob['p.x1'][0], 0.5)
+        assert_near_equal(prob.get_val('p.x1')[0], 0.5)
+
+    def test_options(self):
+        class Parameters(om.IndepVarComp):
+            def initialize(self):
+                self.options.declare('num_x', default=0)
+                self.options.declare('val_y', default=0.)
+
+            def setup(self):
+                self.add_discrete_output('num_x', val = np.zeros(self.options['num_x']))
+                self.add_output('val_y',val = self.options['val_y'])
+
+        prob = om.Problem(model=Parameters(num_x=4, val_y=2.5))
+        prob.setup()
+        prob.run_model()
+
+        self.assertEqual(len(prob.get_val('num_x')), 4)
+        self.assertEqual(prob.get_val('val_y'), 2.5)
 
 
 if __name__ == '__main__':
