@@ -15,7 +15,10 @@ import traceback
 import numpy as np
 from scipy.sparse import coo_matrix
 
-from pyoptsparse import Optimization
+try:
+    from pyoptsparse import Optimization
+except ImportError:
+    Optimization = None
 
 from openmdao.core.analysis_error import AnalysisError
 from openmdao.core.driver import Driver, RecordingDebugging
@@ -117,7 +120,7 @@ class pyOptSparseDriver(Driver):
         Contains the objectives plus nonlinear constraints.
     _signal_cache : <Function>
         Cached function pointer that was assigned as handler for signal defined in option
-        user_teriminate_signal.
+        user_terminate_signal.
     _user_termination_flag : bool
         This is set to True when the user sends a signal to terminate the job.
     """
@@ -131,6 +134,9 @@ class pyOptSparseDriver(Driver):
         **kwargs : dict of keyword arguments
             Keyword arguments that will be mapped into the Driver options.
         """
+        if Optimization is None:
+            raise RuntimeError('pyOptSparseDriver is not available, pyOptsparse is not installed.')
+
         super(pyOptSparseDriver, self).__init__(**kwargs)
 
         # What we support
@@ -182,10 +188,17 @@ class pyOptSparseDriver(Driver):
         self.options.declare('gradient method', default='openmdao',
                              values={'openmdao', 'pyopt_fd', 'snopt_fd'},
                              desc='Finite difference implementation to use')
-        self.options.declare('user_teriminate_signal', default=signal.SIGUSR1, allow_none=True,
-                             desc='OS signal that triggers a clean user-terimnation. Only SNOPT'
+        self.options.declare('user_terminate_signal', default=signal.SIGUSR1, allow_none=True,
+                             desc='OS signal that triggers a clean user-termination. Only SNOPT'
                              'supports this option.')
 
+        # Deprecated option
+        self.options.declare('user_teriminate_signal', default=None, allow_none=True,
+                             desc='OS signal that triggers a clean user-termination. Only SNOPT'
+                             'supports this option.',
+                             deprecation="The option 'user_teriminate_signal' was misspelled and "
+                             "will be deprecated. Please use 'user_terminate_signal' instead.")
+
     def _setup_driver(self, problem):
         """
         Prepare the driver for execution.
@@ -210,6 +223,11 @@ class pyOptSparseDriver(Driver):
 
         self._setup_tot_jac_sparsity()
 
+        # Handle deprecated option.
+        if self.options._dict['user_teriminate_signal']['value'] is not None:
+            self.options['user_terminate_signal'] = \
+                self.options._dict['user_teriminate_signal']['value']
+
     def run(self):
         """
         Excute pyOptsparse.
@@ -274,7 +292,8 @@ class pyOptSparseDriver(Driver):
         param_vals = self.get_design_var_values()
 
         for name, meta in param_meta.items():
-            opt_prob.addVarGroup(name, meta['size'], type='c',
+            size = meta['global_size'] if meta['distributed'] else meta['size']
+            opt_prob.addVarGroup(name, size, type='c',
                                  value=param_vals[name],
                                  lower=meta['lower'], upper=meta['upper'])
 
@@ -310,13 +329,13 @@ class pyOptSparseDriver(Driver):
         for name, meta in con_meta.items():
             if meta['equals'] is None:
                 continue
-            size = meta['size']
+            size = meta['global_size'] if meta['distributed'] else meta['size']
             lower = upper = meta['equals']
             if fwd:
-                wrt = [v for v in indep_list if name in relevant[v]]
+                wrt = [v for v in indep_list if name in relevant[param_meta[v]['ivc_source']]]
             else:
                 rels = relevant[name]
-                wrt = [v for v in indep_list if v in rels]
+                wrt = [v for v in indep_list if param_meta[v]['ivc_source'] in rels]
 
             if meta['linear']:
                 jac = {w: _lin_jacs[name][w] for w in wrt}
@@ -335,17 +354,17 @@ class pyOptSparseDriver(Driver):
         for name, meta in con_meta.items():
             if meta['equals'] is not None:
                 continue
-            size = meta['size']
+            size = meta['global_size'] if meta['distributed'] else meta['size']
 
             # Bounds - double sided is supported
             lower = meta['lower']
             upper = meta['upper']
 
             if fwd:
-                wrt = [v for v in indep_list if name in relevant[v]]
+                wrt = [v for v in indep_list if name in relevant[param_meta[v]['ivc_source']]]
             else:
                 rels = relevant[name]
-                wrt = [v for v in indep_list if v in rels]
+                wrt = [v for v in indep_list if param_meta[v]['ivc_source'] in rels]
 
             if meta['linear']:
                 jac = {w: _lin_jacs[name][w] for w in wrt}
@@ -444,7 +463,7 @@ class pyOptSparseDriver(Driver):
             pass
 
         # revert signal handler to cached version
-        sigusr = self.options['user_teriminate_signal']
+        sigusr = self.options['user_terminate_signal']
         if sigusr is not None:
             signal.signal(sigusr, self._signal_cache)
             self._signal_cache = None   # to prevent memory leak test from failing
@@ -477,7 +496,7 @@ class pyOptSparseDriver(Driver):
 
         # Note: we place our handler as late as possible so that codes that run in the
         # workflow can place their own handlers.
-        sigusr = self.options['user_teriminate_signal']
+        sigusr = self.options['user_terminate_signal']
         if sigusr is not None and self._signal_cache is None:
             self._signal_cache = signal.getsignal(sigusr)
             signal.signal(sigusr, self._signal_handler)
@@ -532,6 +551,7 @@ class pyOptSparseDriver(Driver):
 
         # print("Functions calculated")
         # print(dv_dict)
+        # print(func_dict, flush=True)
 
         self._in_user_function = False
         return func_dict, fail
@@ -625,7 +645,7 @@ class pyOptSparseDriver(Driver):
 
         # print("Derivatives calculated")
         # print(dv_dict)
-        # print(sens_dict)
+        # print(sens_dict, flush=True)
         self._in_user_function = False
         return sens_dict, fail
 
