@@ -287,8 +287,7 @@ class TestJacobian(unittest.TestCase):
     def _check_fwd(self, prob, check_vec):
         d_inputs, d_outputs, d_residuals = prob.model.get_linear_vectors()
 
-        work = d_outputs._clone()
-        work.set_const(1.0)
+        work = np.ones(d_outputs._data.size)
 
         # fwd apply_linear test
         d_outputs.set_const(1.0)
@@ -308,8 +307,7 @@ class TestJacobian(unittest.TestCase):
     def _check_rev(self, prob, check_vec):
         d_inputs, d_outputs, d_residuals = prob.model.get_linear_vectors()
 
-        work = d_outputs._clone()
-        work.set_const(1.0)
+        work = np.ones(d_outputs._data.size)
 
         # rev apply_linear test
         d_residuals.set_const(1.0)
@@ -346,7 +344,7 @@ class TestJacobian(unittest.TestCase):
 
         prob = Problem()
         comp = ExplicitSetItemComp(dtype, value, shape, constructor)
-        prob.model.add_subsystem('C1', comp)
+        comp = prob.model.add_subsystem('C1', comp)
         prob.setup()
 
         prob.set_solver_print(level=0)
@@ -355,7 +353,7 @@ class TestJacobian(unittest.TestCase):
         prob.model.run_linearize()
 
         expected = constructor(value)
-        J = prob.model._subsystems_allprocs[0]._jacobian
+        J = comp._jacobian
         jac_out = J['out', 'in']
 
         self.assertEqual(len(jac_out.shape), 2)
