@@ -60,13 +60,19 @@ class Case(object):
         Dictionary mapping absolute names of all variables to promoted names.
     _abs2meta : dict
         Dictionary mapping absolute names of all variables to variable metadata.
+    _conns : dict
+        Dictionary of all model connections.
+    _auto_ivc_map : dict
+        Dictionary that maps all auto_ivc sources to either an absolute input name for single
+        connections or a promoted input name for multiple connections. This is for output display.
     _var_info : dict
         Dictionary with information about variables (scaling, indices, execution order).
     _format_version : int
         A version number specifying the format of array data, if not numpy arrays.
     """
 
-    def __init__(self, source, data, prom2abs, abs2prom, abs2meta, var_info, data_format=None):
+    def __init__(self, source, data, prom2abs, abs2prom, abs2meta, conns, auto_ivc_map, var_info,
+                 data_format=None):
         """
         Initialize.
 
@@ -82,6 +88,12 @@ class Case(object):
             Dictionary mapping absolute names of all variables to promoted names.
         abs2meta : dict
             Dictionary mapping absolute names of all variables to variable metadata.
+        conns : dict
+            Dictionary of all model connections.
+        auto_ivc_map : dict
+            Dictionary that maps all auto_ivc sources to either an absolute input name for single
+            connections or a promoted input name for multiple connections. This is for output
+            display.
         var_info : dict
             Dictionary with information about variables (scaling, indices, execution order).
         data_format : int
@@ -129,7 +141,7 @@ class Case(object):
 
         if 'inputs' in data.keys():
             if data_format >= 3:
-                inputs = deserialize(data['inputs'], abs2meta)
+                inputs = deserialize(data['inputs'], abs2meta, prom2abs, conns)
             elif data_format in (1, 2):
                 inputs = blob_to_array(data['inputs'])
                 if type(inputs) is np.ndarray and not inputs.shape:
@@ -141,7 +153,7 @@ class Case(object):
 
         if 'outputs' in data.keys():
             if data_format >= 3:
-                outputs = deserialize(data['outputs'], abs2meta)
+                outputs = deserialize(data['outputs'], abs2meta, prom2abs, conns)
             elif self._format_version in (1, 2):
                 outputs = blob_to_array(data['outputs'])
                 if type(outputs) is np.ndarray and not outputs.shape:
@@ -149,11 +161,13 @@ class Case(object):
             else:
                 outputs = data['outputs']
             if outputs is not None:
-                self.outputs = PromAbsDict(outputs, prom2abs['output'], abs2prom['output'])
+                self.outputs = PromAbsDict(outputs, prom2abs['output'], abs2prom['output'],
+                                           in_prom2abs=prom2abs['input'],
+                                           auto_ivc_map=auto_ivc_map)
 
         if 'residuals' in data.keys():
             if data_format >= 3:
-                residuals = deserialize(data['residuals'], abs2meta)
+                residuals = deserialize(data['residuals'], abs2meta, prom2abs, conns)
             elif data_format in (1, 2):
                 residuals = blob_to_array(data['residuals'])
                 if type(residuals) is np.ndarray and not residuals.shape:
@@ -161,7 +175,9 @@ class Case(object):
             else:
                 residuals = data['residuals']
             if residuals is not None:
-                self.residuals = PromAbsDict(residuals, prom2abs['output'], abs2prom['output'])
+                self.residuals = PromAbsDict(residuals, prom2abs['output'], abs2prom['output'],
+                                             in_prom2abs=prom2abs['input'],
+                                             auto_ivc_map=auto_ivc_map)
 
         if 'jacobian' in data.keys():
             if data_format >= 2:
@@ -171,12 +187,16 @@ class Case(object):
             else:
                 jacobian = data['jacobian']
             if jacobian is not None:
-                self.derivatives = PromAbsDict(jacobian, prom2abs['output'], abs2prom['output'])
+                self.derivatives = PromAbsDict(jacobian, prom2abs['output'], abs2prom['output'],
+                                               in_prom2abs=prom2abs['input'],
+                                               auto_ivc_map=auto_ivc_map)
 
         # save var name & meta dict references for use by self._get_variables_of_type()
         self._prom2abs = prom2abs
         self._abs2prom = abs2prom
         self._abs2meta = abs2meta
+        self._conns = conns
+        self._auto_ivc_map = auto_ivc_map
 
         # save VOI dict reference for use by self._scale()
         self._var_info = var_info
@@ -210,6 +230,8 @@ class Case(object):
             try:
                 return self.outputs[name]
             except KeyError:
+                if name in self._auto_ivc_map:
+                    return self.inputs[self._auto_ivc_map[name]]
                 if self.inputs is not None:
                     return self.inputs[name]
         elif self.inputs is not None:
@@ -481,6 +503,7 @@ class Case(object):
                      tags=None,
                      includes=None,
                      excludes=None,
+                     list_autoivcs=False,
                      out_stream=_DEFAULT_OUT_STREAM):
         """
         Return and optionally log a list of output names and other optional information.
@@ -530,6 +553,8 @@ class Case(object):
         excludes : None or list_like
             List of glob patterns for pathnames to exclude from the check. Default is None, which
             excludes nothing.
+        list_autoivcs : bool
+            If True, include auto_ivc outputs in the listing.  Defaults to False.
         out_stream : file-like
             Where to send human readable output. Default is sys.stdout.
             Set to None to suppress.
@@ -544,6 +569,9 @@ class Case(object):
         impl_outputs = []
 
         for var_name in self.outputs.absolute_names():
+            if not list_autoivcs and var_name.startswith('_auto_ivc.'):
+                continue
+
             # Filter based on tags
             if tags and not (make_set(tags) & make_set(meta[var_name]['tags'])):
                 continue
@@ -684,11 +712,27 @@ class Case(object):
         if self.outputs is None:
             return PromAbsDict({}, self._prom2abs, self._abs2prom)
 
+        abs2meta = self._abs2meta
+        prom2abs = self._prom2abs['input']
+        conns = self._conns
+        auto_ivc_map = self._auto_ivc_map
+
         ret_vars = {}
         update_vals = scaled or use_indices
         for name in self.outputs.absolute_names():
-            if var_type in self._abs2meta[name]['type']:
-                ret_vars[name] = val = self.outputs[name]
+            if name in abs2meta:
+                type_match = var_type in abs2meta[name]['type']
+            elif name in prom2abs:
+                abs_name = prom2abs[name][0]
+                src_name = conns[abs_name]
+                type_match = var_type in abs2meta[src_name]['type']
+
+            if type_match:
+                if name in auto_ivc_map:
+                    return_name = auto_ivc_map[name]
+                else:
+                    return_name = name
+                ret_vars[return_name] = val = self.outputs[name]
                 if update_vals and name in self._var_info:
                     meta = self._var_info[name]
                     if use_indices and meta['indices'] is not None:
@@ -698,9 +742,10 @@ class Case(object):
                             val += meta['total_adder']
                         if meta['total_scaler'] is not None:
                             val *= meta['total_scaler']
-                    ret_vars[name] = val
+                    ret_vars[return_name] = val
 
-        return PromAbsDict(ret_vars, self._prom2abs['output'], self._abs2prom['output'])
+        return PromAbsDict(ret_vars, self._prom2abs['output'], self._abs2prom['output'],
+                           in_prom2abs=prom2abs, auto_ivc_map=auto_ivc_map)
 
 
 class PromAbsDict(dict):
@@ -714,14 +759,18 @@ class PromAbsDict(dict):
     _keys : array
         Absolute variable names that map to the values in the _values array.
     _prom2abs : dict
-        Dictionary mapping promoted names to absolute names.
+        Dictionary mapping promoted names in the output vector to absolute names.
     _abs2prom : dict
         Dictionary mapping absolute names to promoted names.
+    _auto_ivc_map : dict
+        Dictionary that maps all auto_ivc sources to either an absolute input name for single
+        connections or a promoted input name for multiple connections. This is for output display.
     _DERIV_KEY_SEP : str
         Separator character for derivative keys.
     """
 
-    def __init__(self, values, prom2abs, abs2prom, data_format=current_version):
+    def __init__(self, values, prom2abs, abs2prom, data_format=current_version,
+                 in_prom2abs=None, auto_ivc_map=None):
         """
         Initialize.
 
@@ -732,14 +781,22 @@ class PromAbsDict(dict):
         prom2abs : dict
             Dictionary mapping promoted names to absolute names.
         abs2prom : dict
-            Dictionary mapping absolute names to promoted names.
+            Dictionary mapping absolute names in the output vector to promoted names.
         data_format : int
             A version number specifying the OpenMDAO SQL case database version.
+        in_prom2abs : dict
+           Dictionary mapping promoted names in the input vector to absolute names.
+        auto_ivc_map : dict
+            Dictionary that maps all auto_ivc sources to either an absolute input name for single
+            connections or a promoted input name for multiple connections. This is for output
+            display.
         """
         super(PromAbsDict, self).__init__()
 
         self._prom2abs = prom2abs
         self._abs2prom = abs2prom
+        auto_ivc_map = auto_ivc_map if auto_ivc_map is not None else {}
+        self._auto_ivc_map = auto_ivc_map
 
         if data_format <= 8:
             DERIV_KEY_SEP = self._DERIV_KEY_SEP = ','
@@ -750,7 +807,12 @@ class PromAbsDict(dict):
             # dict of values, keyed on either absolute or promoted names
             self._values = {}
             for key in values.keys():
-                if key in abs2prom:
+                if key in auto_ivc_map:
+                    # key is auto_ivc, so translate to a readable input name.
+                    self._values[key] = values[key]
+                    in_key = auto_ivc_map[key]
+                    super(PromAbsDict, self).__setitem__(in_key, values[key])
+                elif key in abs2prom:
                     # key is absolute name
                     self._values[key] = values[key]
                     prom_key = abs2prom[key]
@@ -766,13 +828,21 @@ class PromAbsDict(dict):
                     for abs_key in abs_keys:
                         self._values[abs_key] = values[key]
                     super(PromAbsDict, self).__setitem__(prom_key, values[key])
+                elif in_prom2abs is not None and key in in_prom2abs:
+                    # Auto-ivc outputs, use abs source (which is prom source.)
+                    self._values[key] = values[key]
+                    super(PromAbsDict, self).__setitem__(key, values[key])
             self._keys = self._values.keys()
         else:
             # numpy structured array, which will always use absolute names
             self._values = values[0]
             self._keys = values.dtype.names
             for key in self._keys:
-                if key in abs2prom:
+                if key in auto_ivc_map:
+                    # key is auto_ivc, so translate to a readable input name.
+                    in_key = auto_ivc_map[key]
+                    super(PromAbsDict, self).__setitem__(in_key, self._values[key])
+                elif key in abs2prom:
                     prom_key = abs2prom[key]
                     if prom_key in self:
                         # We already set a value for this promoted name, which means
@@ -785,6 +855,10 @@ class PromAbsDict(dict):
                     # derivative keys will be a string in the form of 'of!wrt'
                     abs_keys, prom_key = self._deriv_keys(key)
                     super(PromAbsDict, self).__setitem__(prom_key, self._values[key])
+                elif in_prom2abs is not None and key in in_prom2abs:
+                    # Auto-ivc outputs, use abs source (which is prom source.)
+                    # TODO - maybe get rid of this by always saving the source name
+                    super(PromAbsDict, self).__setitem__(key, self._values[key])
 
     def __str__(self):
         """
@@ -826,11 +900,19 @@ class PromAbsDict(dict):
 
         # if promoted, will map to all connected absolute names
         abs_of = [of] if of in abs2prom else prom2abs[of]
-        abs_wrt = [wrt] if wrt in abs2prom else prom2abs[wrt]
+        if wrt in prom2abs:
+            abs_wrt = [prom2abs[wrt]][0]
+        else:
+            abs_wrt = [wrt]
+
         abs_keys = ['%s%s%s' % (o, DERIV_KEY_SEP, w) for o, w in itertools.product(abs_of, abs_wrt)]
 
         prom_of = of if of in prom2abs else abs2prom[of]
-        prom_wrt = wrt if wrt in prom2abs else abs2prom[wrt]
+        if wrt in abs2prom:
+            prom_wrt = abs2prom[wrt]
+        else:
+            prom_wrt = wrt
+
         prom_key = (prom_of, prom_wrt)
 
         return abs_keys, prom_key
@@ -853,6 +935,12 @@ class PromAbsDict(dict):
             # absolute name
             return self._values[key]
 
+        elif key in self._auto_ivc_map:
+            # We allow the user to query with auto_ivc varname.
+            src_key = self._auto_ivc_map[key]
+            if src_key in self._keys:
+                return self._values[self._auto_ivc_map[key]]
+
         elif key in self:
             # promoted name
             val = super(PromAbsDict, self).__getitem__(key)
@@ -882,6 +970,10 @@ class PromAbsDict(dict):
         value : any
             value for variable
         """
+        auto_ivc_map = self._auto_ivc_map
+        abs2prom = self._abs2prom
+        prom2abs = self._prom2abs
+
         if isinstance(key, tuple) or self._DERIV_KEY_SEP in key:
             # derivative keys can be either (of, wrt) or 'of!wrt'
             abs_keys, prom_key = self._deriv_keys(key)
@@ -891,16 +983,26 @@ class PromAbsDict(dict):
 
             super(PromAbsDict, self).__setitem__(prom_key, value)
 
-        elif key in self._keys:
-            # absolute name
-            self._values[key] = value
-            super(PromAbsDict, self).__setitem__(self._abs2prom[key], value)
-        else:
+        elif key in abs2prom:
+            if key in auto_ivc_map:
+                # key is auto_ivc, so translate to a readable input name.
+                self._values[key] = value
+                in_key = auto_ivc_map[key]
+                super(PromAbsDict, self).__setitem__(in_key, self._values[key])
+            else:
+                # absolute name
+                self._values[key] = value
+                super(PromAbsDict, self).__setitem__(self._abs2prom[key], value)
+        elif key in prom2abs:
             # promoted name, propagate to all connected absolute names
             for abs_key in self._prom2abs[key]:
                 if abs_key in self._keys:
                     self._values[abs_key] = value
             super(PromAbsDict, self).__setitem__(key, value)
+        else:
+            # Design variable by promoted input name.
+            self._values[key] = value
+            super(PromAbsDict, self).__setitem__(key, value)
 
     def absolute_names(self):
         """
