@@ -226,9 +226,6 @@ class TestScipyKrylovFeature(unittest.TestCase):
         prob = om.Problem()
         model = prob.model
 
-        model.add_subsystem('px', om.IndepVarComp('x', 1.0), promotes=['x'])
-        model.add_subsystem('pz', om.IndepVarComp('z', np.array([5.0, 2.0])), promotes=['z'])
-
         model.add_subsystem('d1', SellarDis1withDerivatives(), promotes=['x', 'z', 'y1', 'y2'])
         model.add_subsystem('d2', SellarDis2withDerivatives(), promotes=['z', 'y1', 'y2'])
 
@@ -244,6 +241,10 @@ class TestScipyKrylovFeature(unittest.TestCase):
         model.linear_solver = om.ScipyKrylov()
 
         prob.setup()
+
+        prob.set_val('x', 1.)
+        prob.set_val('z', np.array([5.0, 2.0]))
+
         prob.run_model()
 
         wrt = ['z']
@@ -262,9 +263,6 @@ class TestScipyKrylovFeature(unittest.TestCase):
         prob = om.Problem()
         model = prob.model
 
-        model.add_subsystem('px', om.IndepVarComp('x', 1.0), promotes=['x'])
-        model.add_subsystem('pz', om.IndepVarComp('z', np.array([5.0, 2.0])), promotes=['z'])
-
         model.add_subsystem('d1', SellarDis1withDerivatives(), promotes=['x', 'z', 'y1', 'y2'])
         model.add_subsystem('d2', SellarDis2withDerivatives(), promotes=['z', 'y1', 'y2'])
 
@@ -281,6 +279,10 @@ class TestScipyKrylovFeature(unittest.TestCase):
         model.linear_solver.options['maxiter'] = 3
 
         prob.setup()
+
+        prob.set_val('x', 1.)
+        prob.set_val('z', np.array([5.0, 2.0]))
+
         prob.run_model()
 
         wrt = ['z']
@@ -299,9 +301,6 @@ class TestScipyKrylovFeature(unittest.TestCase):
         prob = om.Problem()
         model = prob.model
 
-        model.add_subsystem('px', om.IndepVarComp('x', 1.0), promotes=['x'])
-        model.add_subsystem('pz', om.IndepVarComp('z', np.array([5.0, 2.0])), promotes=['z'])
-
         model.add_subsystem('d1', SellarDis1withDerivatives(), promotes=['x', 'z', 'y1', 'y2'])
         model.add_subsystem('d2', SellarDis2withDerivatives(), promotes=['z', 'y1', 'y2'])
 
@@ -318,6 +317,10 @@ class TestScipyKrylovFeature(unittest.TestCase):
         model.linear_solver.options['atol'] = 1.0e-20
 
         prob.setup()
+
+        prob.set_val('x', 1.)
+        prob.set_val('z', np.array([5.0, 2.0]))
+
         prob.run_model()
 
         wrt = ['z']
@@ -361,8 +364,8 @@ class TestScipyKrylovFeature(unittest.TestCase):
         prob.set_solver_print(level=2)
         prob.run_model()
 
-        assert_near_equal(prob['sub1.q1.x'], 1.996, .0001)
-        assert_near_equal(prob['sub2.q2.x'], 1.996, .0001)
+        assert_near_equal(prob.get_val('sub1.q1.x'), 1.996, .0001)
+        assert_near_equal(prob.get_val('sub2.q2.x'), 1.996, .0001)
 
 
 if __name__ == "__main__":
