@@ -29,8 +29,8 @@ class TestSolverFeatures(unittest.TestCase):
         prob.setup()
         prob.run_model()
 
-        assert_near_equal(prob['y1'], 25.58830273, .00001)
-        assert_near_equal(prob['y2'], 12.05848819, .00001)
+        assert_near_equal(prob.get_val('y1'), 25.58830273, .00001)
+        assert_near_equal(prob.get_val('y2'), 12.05848819, .00001)
 
     def test_specify_subgroup_solvers(self):
         import openmdao.api as om
@@ -56,10 +56,10 @@ class TestSolverFeatures(unittest.TestCase):
         prob.setup()
         prob.run_model()
 
-        assert_near_equal(prob['g1.y1'], 0.64, .00001)
-        assert_near_equal(prob['g1.y2'], 0.80, .00001)
-        assert_near_equal(prob['g2.y1'], 0.64, .00001)
-        assert_near_equal(prob['g2.y2'], 0.80, .00001)
+        assert_near_equal(prob.get_val('g1.y1'), 0.64, .00001)
+        assert_near_equal(prob.get_val('g1.y2'), 0.80, .00001)
+        assert_near_equal(prob.get_val('g2.y1'), 0.64, .00001)
+        assert_near_equal(prob.get_val('g2.y2'), 0.80, .00001)
 
 
 if __name__ == "__main__":
