@@ -17,7 +17,7 @@ if __name__ == '__main__':
     prob.setup()
     prob.run_driver()
 
-    assert np.linalg.norm(prob['inputs_comp.h'] - [
+    assert np.linalg.norm(prob['h'] - [
         0.14915754,  0.14764328,  0.14611321,  0.14456715,  0.14300421,  0.14142417,
         0.13982611,  0.13820976,  0.13657406,  0.13491866,  0.13324268,  0.13154528,
         0.12982575,  0.12808305,  0.12631658,  0.12452477,  0.12270701,  0.12086183,
