@@ -18,25 +18,29 @@ class N2Layout {
      * @param {boolean} showLinearSolverNames Whether to show linear or non-linear solver names.
      * @param {Object} dims The initial sizes for multiple tree elements.
      */
-    constructor(model, newZoomedElement,
-        showLinearSolverNames, dims) {
+    constructor(model, newZoomedElement, showLinearSolverNames, dims) {
         this.model = model;
 
         this.zoomedElement = newZoomedElement;
         this.showLinearSolverNames = showLinearSolverNames;
 
-
         this.outputNamingType = "Absolute";
         this.zoomedNodes = [];
         this.visibleNodes = [];
 
         this.zoomedSolverNodes = [];
         this.visibleSolverNodes = [];
+        this.curVisibleNodeCount = 0;
+        this.prevVisibleNodeCount = 0;
 
         // Initial size values derived from read-only defaults
         this.size = dims.size;
         this.svg = d3.select("#svgId");
 
+        startTimer('N2Layout._computeLeaves');
+        this._computeLeaves();
+        stopTimer('N2Layout._computeLeaves');
+
         this._setupTextRenderer();
         startTimer('N2Layout._updateTextWidths');
         this._updateTextWidths();
@@ -45,11 +49,7 @@ class N2Layout {
         startTimer('N2Layout._updateSolverTextWidths');
         this._updateSolverTextWidths();
         stopTimer('N2Layout._updateSolverTextWidths');
-        delete(this.textRenderer);
-
-        startTimer('N2Layout._computeLeaves');
-        this._computeLeaves();
-        stopTimer('N2Layout._computeLeaves');
+        delete (this.textRenderer);
 
         startTimer('N2Layout._computeColumnWidths');
         this._computeColumnWidths();
@@ -87,8 +87,12 @@ class N2Layout {
      * the original transition methods are restored.
      */
     setTransitionPermission() {
+        this.prevVisibleNodeCount = this.visibleNodeCount;
+        this.visibleNodeCount = this.visibleNodes.length;
+        const highWaterMark = Math.max(this.prevVisibleNodeCount, this.visibleNodeCount);
+
         // Too many nodes, disable transitions.
-        if (this.visibleNodes.length >= N2TransitionDefaults.maxNodes) {
+        if (highWaterMark >= N2TransitionDefaults.maxNodes) {
             debugInfo("Denying transitions: ", this.visibleNodes.length,
                 " visible nodes, max allowed: ", N2TransitionDefaults.maxNodes)
 
@@ -117,10 +121,8 @@ class N2Layout {
 
     /** Create an off-screen area to render text for _getTextWidth() */
     _setupTextRenderer() {
-        let textGroup = this.svg.append("g").attr("class", "partition_group");
-        let textSVG = textGroup.append("text")
-            .text("")
-            .attr("x", -100); // Put text off screen to the left.
+        const textGroup = this.svg.select('#text-width-renderer');
+        const textSVG = textGroup.select('text');
 
         this.textRenderer = {
             'group': textGroup,
@@ -201,7 +203,7 @@ class N2Layout {
         node.nameWidthPx = this._getTextWidth(this.getText(node)) + 2 *
             this.size.rightTextMargin;
 
-        if (node.hasChildren()) {
+        if (node.hasChildren() && !node.isMinimized) {
             for (let child of node.children) {
                 this._updateTextWidths(child);
             }
@@ -220,7 +222,7 @@ class N2Layout {
         node.nameSolverWidthPx = this._getTextWidth(this.getSolverText(node)) + 2 *
             this.size.rightTextMargin;
 
-        if (node.hasChildren()) {
+        if (node.hasChildren() && !node.isMinimized) {
             for (let child of node.children) {
                 this._updateSolverTextWidths(child);
             }
@@ -228,22 +230,24 @@ class N2Layout {
     }
 
     /** Recurse through the tree and add up the number of leaves that each
-     * node has, based on their array of children.
+     * node has, based on their array of visible children.
      * @param {N2TreeNode} [node = this.model.root] The starting node.
      */
     _computeLeaves(node = this.model.root) {
-        if (node.varIsHidden) {
-            node.numLeaves = 0;
-        }
-        else if (node.hasChildren() && !node.isMinimized) {
-            node.numLeaves = 0;
-            for (let child of node.children) {
-                this._computeLeaves(child);
-                node.numLeaves += child.numLeaves;
+        node.numLeaves = 0;
+
+        if (! node.varIsHidden) {
+            if (this.model.idCounter > ALLOW_PRECOLLAPSE_COUNT) node.minimizeIfLarge();
+
+            if (node.hasChildren() && !node.isMinimized) {
+                for (let child of node.children) {
+                    this._computeLeaves(child);
+                    node.numLeaves += child.numLeaves;
+                }
+            }
+            else {
+                node.numLeaves = 1;
             }
-        }
-        else {
-            node.numLeaves = 1;
         }
     }
 
@@ -285,8 +289,8 @@ class N2Layout {
         this.greatestDepth = 0;
         this.leafWidthsPx = new Array(this.model.maxDepth + 1).fill(0.0);
         this.cols = Array.from({
-                length: this.model.maxDepth + 1
-            }, () =>
+            length: this.model.maxDepth + 1
+        }, () =>
             ({
                 'width': 0.0,
                 'location': 0.0
@@ -314,8 +318,8 @@ class N2Layout {
         this.greatestDepth = 0;
         this.leafSolverWidthsPx = new Array(this.model.maxDepth + 1).fill(0.0);
         this.solverCols = Array.from({
-                length: this.model.maxDepth + 1
-            }, () =>
+            length: this.model.maxDepth + 1
+        }, () =>
             ({
                 'width': 0.0,
                 'location': 0.0
@@ -511,32 +515,55 @@ class N2Layout {
      * @param {Object} dom References to HTML elements.
      * @param {number} transitionStartDelay ms to wait before performing transition
      */
-    updateTransitionInfo(dom, transitionStartDelay) {
+    updateTransitionInfo(dom, transitionStartDelay, manuallyResized) {
+
         sharedTransition = d3.transition()
             .duration(N2TransitionDefaults.duration)
-            .delay(transitionStartDelay);
+            .delay(transitionStartDelay)
+            // Hide the transition waiting animation when it ends:
+            .on('end', function() { dom.waiter.attr('class', 'no-show'); });
 
         this.transitionStartDelay = N2TransitionDefaults.startDelay;
 
         let outerDims = this.newOuterDims();
         let innerDims = this.newInnerDims();
 
-        dom.svgDiv.transition(sharedTransition)
-            .style("width", outerDims.width + this.size.unit)
-            .style("height", outerDims.height + this.size.unit);
+        this.ratio = (window.innerWidth - 200) / outerDims.width;
+        if (this.ratio > 1 || manuallyResized) this.ratio = 1;
+        else if (this.ratio < 1)
+            debugInfo("Scaling diagram to " + Math.round(this.ratio * 100) + "%");
 
-        dom.svg.transition(sharedTransition)
-            .attr("width", outerDims.width)
-            .attr("height", outerDims.height)
-            .attr("transform", "translate(0 0)");
+        dom.svgDiv
+            .style("width", (outerDims.width * this.ratio) + this.size.unit)
+            .style("height", (outerDims.height * this.ratio) + this.size.unit)
 
-        dom.pTreeGroup.transition(sharedTransition)
+        dom.svg
+            .transition(sharedTransition)
+            .style("transform", "scale(" + this.ratio + ")")
+            .attr("width", outerDims.width + this.size.unit)
+            .attr("height", outerDims.height + this.size.unit);
+
+        this.gapDist = (this.size.partitionTreeGap * this.ratio) - 3;
+        this.gapSpace = this.gapDist + this.size.unit
+        d3.select('#n2-resizer-box')
+            .transition(sharedTransition)
+            .style('bottom', this.gapSpace);
+
+        dom.pTreeGroup
+            .transition(sharedTransition)
             .attr("height", innerDims.height)
             .attr("width", this.size.partitionTree.width)
             .attr("transform", "translate(0 " + innerDims.margin + ")");
 
+        dom.highlightBar
+            .transition(sharedTransition)
+            .attr("height", innerDims.height)
+            .attr("width", "8")
+            .attr("transform", "translate(" + this.size.partitionTree.width + 1 + " " + innerDims.margin + ")");
+
         // Move n2 outer group to right of partition tree, spaced by the margin.
-        dom.n2OuterGroup.transition(sharedTransition)
+        dom.n2OuterGroup
+            .transition(sharedTransition)
             .attr("height", outerDims.height)
             .attr("width", outerDims.height)
             .attr("transform", "translate(" +
@@ -555,9 +582,31 @@ class N2Layout {
         dom.pSolverTreeGroup.transition(sharedTransition)
             .attr("height", innerDims.height)
             .attr("transform", "translate(" + (this.size.partitionTree.width +
-                    innerDims.margin +
-                    innerDims.height +
-                    innerDims.margin) + " " +
+                innerDims.margin +
+                innerDims.height +
+                innerDims.margin) + " " +
                 innerDims.margin + ")");
     }
+
+    calcWidthBasedOnNewHeight(height) {
+        return this.size.partitionTree.width + height + this.size.solverTree.width +
+            this.size.n2matrix.margin * 2;
+    }
+
+    calcHeightBasedOnNewWidth(width) {
+        return width - this.size.partitionTree.width - this.size.solverTree.width -
+            this.size.n2matrix.margin * 2;
+    }
+
+    calcFitDims() {
+        let height = window.innerHeight * 0.95;
+        let width = this.calcWidthBasedOnNewHeight(height);
+
+        if (width > window.innerWidth - 200) {
+            width = window.innerWidth - 200;
+            height = this.calcHeightBasedOnNewWidth(width);
+        }
+
+        return { 'width': width, 'height': height };
+    }
 }
\ No newline at end of file
