@@ -175,12 +175,59 @@ class N2VectorBase extends N2CellRenderer {
      * @param {Object} dims The cell spec to use while rendering.
      */
     render(svgGroup, dims) {
-        let d3Elem = d3.select(svgGroup)
-            .append("rect")
+        let d3Elem = d3.select(svgGroup).append('rect')
             .attr("class", this.className)
             .attr("id", this.id)
             .style("fill", this.color);
-        return this.update(svgGroup, dims, d3Elem)
+
+        return this.update(svgGroup, dims, d3Elem);
+    }
+}
+
+class N2Connector extends N2CellRenderer {
+    /**
+     * Invoke the superclass constructor with these values and "vMid" as a CSS class.
+     * @param {Object} dims Layout and dimensions for the current cell spec.
+     * @param {Object} prevDims Layout and dimensions for the previous cell spec.
+     * @param {string} color The color to render all shapes in.
+     */
+    constructor(color, id) {
+        super(color, "vMid", id);
+    }
+
+    _transform(scale) { throw ("ERROR: N2Connector._transform() called.") }
+
+    /**
+     * Select the element with D3 if not already done, attach a transition
+     * and resize the shape.
+     * @param svgGroup Reference to SVG <g> element associated with data.
+     * @param {Object} dims The cell spec to use while resizing/repositioning.
+     * @param {selection} [d3Elem = null ] The selection created in render().
+     */
+    update(svgGroup, dims, d3Elem = null) {
+        if (!d3Elem) d3Elem = d3.select(svgGroup).select("." + this.className)
+            .transition(sharedTransition);
+
+        let ret = d3Elem.attr("transform", this._transform(dims.size.width/10.0));
+
+        return ret;
+    }
+
+    /** 
+     * Get the D3 selection for the appropriate group and append a filled arrow.
+     * @param {Object} svgGroup Reference to SVG <g> element associated with data.
+     * @param {Object} dims The cell spec to use while rendering.
+     */
+    render(svgGroup, dims) {
+        let d3Elem = d3.select(svgGroup).append('use')
+            .attr("class", this.className)
+            .attr("id", this.id)
+            .style("fill", this.color)
+            .attr("x", -5)
+            .attr("y", -5)
+            .attr("xlink:href", "#matrix-connector-square")
+
+        return this.update(svgGroup, dims, d3Elem);
     }
 }
 
@@ -329,6 +376,24 @@ class N2VectorVectorCell extends N2VectorBase {
     }
 }
 
+class N2ConnectorUpper extends N2Connector {
+    constructor(color, id) {
+        super(color, id);
+    }
+
+    /** Generate a string to use for the transform attribute */
+    _transform(scale) { return('scale(' + scale + ')'); }
+}
+
+class N2ConnectorLower extends N2Connector {
+    constructor(color, id) {
+        super(color, id);
+    }
+
+    /** Generate a string to use for the transform attribute */
+    _transform(scale) { return('scale(' + scale + ') rotate(180)'); }
+}
+
 class N2ScalarGroupCell extends N2GroupBase {
     constructor(color, id) {
         super(color, id);
@@ -412,6 +477,22 @@ class N2MatrixCell {
         return (this.row == this.col);
     }
 
+    /**
+     * Determine if this node is in the upper-right triangle of the matrix.
+     * @return {Boolean} True if column is greater than row.
+     */
+    inUpperTriangle() {
+        return (this.col > this.row);
+    }
+
+    /**
+     * Determine if this node is in the lower-left triangle of the matrix.
+     * @return {Boolean} True if row is greater than column.
+     */
+    inLowerTriangle() {
+        return (this.row > this.col);
+    }
+
     /**
      * Select the mouseover callback depending on whether we"re on the diagonal.
      * TODO: Remove these globals
@@ -421,10 +502,10 @@ class N2MatrixCell {
             n2MouseFuncs.overOffDiag);
     }
 
-     /**
-     * Select the mousemove callback depending on whether we"re on the diagonal.
-     * TODO: Remove these globals
-     */
+    /**
+    * Select the mousemove callback depending on whether we"re on the diagonal.
+    * TODO: Remove these globals
+    */
     mousemove() {
         return (this.onDiagonal() ? n2MouseFuncs.moveOnDiag : null);
     }
@@ -433,8 +514,12 @@ class N2MatrixCell {
      * Choose a color based on our location and state of the associated N2TreeNode.
      */
     color() {
+        if (this.symbolType.potentialDeclaredPartial &&
+            this.symbolType.declaredPartial) return N2Style.color.declaredPartial;
+
         if (this.onDiagonal()) {
             if (this.obj.isMinimized) return N2Style.color.collapsed;
+            if (this.obj.isAutoIvcParam()) return N2Style.color.autoivcParam;
             if (this.obj.isConnectedParam()) return N2Style.color.param;
             if (this.obj.isUnconnectedParam()) return N2Style.color.unconnectedParam;
             return (this.obj.implicit) ?
@@ -488,36 +573,71 @@ class N2MatrixCell {
         // debugInfo("Total offscreen connections found: " + this.offScreen.total);
     }
 
-    /** Choose a renderer based on our SymbolType.
-     * @param {Object} dims Layout and dimensions for the current cell spec.
-     * @param {Object} prevDims Layout and dimensions for the previous cell spec.
-     */
+    /** Choose a renderer based on our SymbolType. */
     _newRenderer() {
+        if (this.color() == N2Style.color.connection) {
+            if (this.inUpperTriangle()) return new N2ConnectorUpper(this.color(), this.id);
+
+            return new N2ConnectorLower(this.color(), this.id)
+        }
+
+        const color = this.color();
+
         switch (this.symbolType.name) {
             case "scalar":
-                return new N2ScalarCell(this.color(), this.id);
+                return new N2ScalarCell(color, this.id);
             case "vector":
-                return new N2VectorCell(this.color(), this.id);
+                return new N2VectorCell(color, this.id);
             case "group":
-                return new N2GroupCell(this.color(), this.id);
+                return new N2GroupCell(color, this.id);
             case "scalarScalar":
-                return new N2ScalarScalarCell(this.color(), this.id);
+                return new N2ScalarScalarCell(color, this.id);
             case "scalarVector":
-                return new N2ScalarVectorCell(this.color(), this.id);
+                return new N2ScalarVectorCell(color, this.id);
             case "vectorScalar":
-                return new N2VectorScalarCell(this.color(), this.id);
+                return new N2VectorScalarCell(color, this.id);
             case "vectorVector":
-                return new N2VectorVectorCell(this.color(), this.id);
+                return new N2VectorVectorCell(color, this.id);
             case "scalarGroup":
-                return new N2ScalarGroupCell(this.color(), this.id);
+                return new N2ScalarGroupCell(color, this.id);
             case "groupScalar":
-                return new N2GroupScalarCell(this.color(), this.id);
+                return new N2GroupScalarCell(color, this.id);
             case "vectorGroup":
-                return new N2VectorGroupCell(this.color(), this.id);
+                return new N2VectorGroupCell(color, this.id);
             case "groupVector":
-                return new N2GroupVectorCell(this.color(), this.id);
+                return new N2GroupVectorCell(color, this.id);
             case "groupGroup":
-                return new N2GroupGroupCell(this.color(), this.id);
+                return new N2GroupGroupCell(color, this.id);
         }
     }
+
+    /**
+     * Highlight the variable nodes *associated* with the cell, not the cell
+     * itself. The default is for cells on the diagonal to highlight the
+     * variable directly across from them.
+     * @param {String} [varType = 'self'] Either 'self', 'source', or 'target'
+     *   to indicate the variable name to highlight.
+     * @param {String} [direction = 'self'] Either 'self', 'input', or 'output'
+     *   to indicate the style of the highlighting.
+     */
+    highlight(varType = 'self', direction = 'self') {
+
+        const obj = (varType == 'target') ? this.tgtObj : this.srcObj;
+        const treeId = obj.absPathName.replace(/[\.:]/g, '_');
+        const treeNode = d3.select('rect#' + treeId);
+
+        let fill = treeNode.style('fill');
+        if (direction == 'input') fill = N2Style.color.input;
+        else if (direction == 'output') fill = N2Style.color.output;
+
+        d3.select('#highlight-bar').append('rect')
+            .attr('x', 0)
+            .attr('y', treeNode.node().parentNode.transform.baseVal[0].matrix.f)
+            .attr('rx', 4)
+            .attr('ry', 4)
+            .attr('width', 8)
+            .attr('height', treeNode.attr('height'))
+            .attr('stroke', N2Style.color.treeStroke)
+            .attr('fill', fill);
+    }
 }
\ No newline at end of file
