@@ -1,5 +1,7 @@
-// Just to make things easier to find:
-const EMBEDDED = (d3.selectAll("#all_pt_n2_content_div").classed("embedded-n2"))
+// Constants and default valus
+const EMBEDDED = (d3.selectAll("#all_pt_n2_content_div").classed("embedded-n2"));
+const ALLOW_PRECOLLAPSE_COUNT = 200; // Consider precollapsing nodes in models larger than this
+const PRECOLLAPSE_THRESHOLD = 10; // Pre-collapse nodes with more descendants than this
 const _DEFAULT_N2_DIAGRAM_UNIT = 'px';
 const _DEFAULT_N2_DIAGRAM_HEIGHT = window.innerHeight * .95;
 const _DEFAULT_FONT_SIZE = 11;
